@@ -1,8 +1,10 @@
 """Wrapper on top of pd.DataFrame with some parallel operations"""
 from multiprocessing import Pool
 import pandas as pd
+
 from .pandas_parallel_apply import apply_on_df_parallel
 from .series_parallel import SeriesParallel
+from .groupby_parallel import GroupByParallel
 
 class DataFrameParallel:
     def __init__(self, df: pd.DataFrame, n_cores: int, pbar: bool = True):
@@ -15,6 +17,9 @@ class DataFrameParallel:
         assert axis == 1
         return apply_on_df_parallel(self.df, func, self.n_cores, self.pbar)
 
+    def groupby(self, *args, **kwargs):
+        return GroupByParallel(self.df.groupby(*args, **kwargs), self.n_cores, self.pbar)
+
     def __getitem__(self, x):
         return SeriesParallel(self.df[x], self.n_cores, self.pbar)
 
